@@ -3,14 +3,21 @@
 #' Run and control charts for multivariate data i trellis (grid) layout.
 #'
 #' @export
-#' @param n Numeric vector of counts or measures to plot. Mandatory.
-#' @param d Numeric vector of sample sizes. Mandatory for P and U charts.
-#' @param x Subgrouping vector used for aggregating data and making x-labels.
-#'   Mandatory for Xbar and S charts.
+#' @import ggplot2
+#' @import ggrepel
+#' @importFrom utils tail
+#'
+#' @param n Numerator, numeric vector of counts or measures to plot. Mandatory.
+#' @param d Denominator, numeric vector of subgroup sizes. Mandatory for P and U
+#'   charts.
+#' @param x Subgrouping vector used for aggregating data by subgroup and making
+#'   x-labels. Mandatory for Xbar and S charts.
 #' @param g1 Grouping vector 1 used for trellis layout (facets).
 #' @param g2 Grouping vector 2 used for trellis layout (facets).
 #' @param breaks Numeric vector of break points. Useful for splitting graph in
 #'   two or more sections with separate center line and control limits.
+#' @param notes Character vector of notes to be added to individual. data
+#'   points.
 #' @param data Data frame containing variables.
 #' @param chart Type of control chart. Possible types are: \itemize{ \item
 #'   "run": run chart (default). \item "i": individuals chart. \item "mr":
@@ -19,44 +26,68 @@
 #'   proportions chart. \item "c": counts chart. \item "u": rates chart. \item
 #'   "g": cases between events chart. }
 #' @param multiply Integer indicating a number to multiply y axis by, e.g. 100
-#'   for percents rather than proportions.
+#'   for percents rather than proportions. See also \code{y.percent} argument.
 #' @param freeze Number identifying the last data point to include in
 #'   calculations of center and limits (ignored if \code{breaks} argument is
 #'   given).
 #' @param exclude Numeric vector of data points to exclude from calculations of
 #'   center and control lines.
-#' @param sum.n Logical value indicating whether the mean (default) or sum of
-#'   counts or measures should be plotted. Only relevant for run charts and I
-#'   charts with multiple counts or measures per subgroup.
-#' @param neg.y Logical value. If TRUE (default), the y axis is allowed to be
+#' @param target Numeric value indicating a target value to be plotted as a
+#'   horizontal line
+#' @param n.sum Logical value indicating whether the mean (default) or sum of
+#'   numerator (n argument) per subgroup should be plotted. Only relevant for
+#'   run, C, and I charts with multiple counts per subgroup.
+#' @param y.neg Logical value. If TRUE (default), the y axis is allowed to be
 #'   negative (only relevant for I and Xbar charts).
+#' @param y.percent Logical. If TRUE, formats y axis labels as percent.
+#' @param y.expand Numeric value to include in y axis. Useful e.g. for beginning
+#'   y axis at zero.
+#' @param x.pad Number indicating expansion of x axis to make room for center
+#'   line labels.
+#' @param x.date.format Date format of x axis labels. See \code{?strftime()} for
+#'   possible date formats.
+#' @param cl.lab Logical value. If TRUE (default), plots center line labels.
+#' @param cl.decimals Number of decimals on center line labels.
+#' @param main Character string specifying the title of the plot.
+#' @param xlab Character string specifying the x axis label.
+#' @param ylab Character string specifying the y axis label.
 #' @param cex Number indicating the amount by which text should be magnified.
 #' @param pex Number indicating the amount by which plotting symbols should be
 #'   magnified.
-#' @param dec Number of decimals on center and control line labels.
-#' @param ylim Range of y axis.
-#' @param date.format Date format of x axis labels. See \code{?strftime()} for
-#'   possible date formats.
-#' @param prime Logical value, If TRUE (default unless dots.only = TRUE),
+#' @param prime Logical value, If TRUE (default unless \code{dots.only = TRUE}),
 #'   control limits incorporate between-subgroup variation as proposed by Laney
 #'   (2002). Only relevant for P and U charts.
 #' @param flip Logical. If TRUE rotates the plot 90 degrees.
 #' @param dots.only Logical value. If TRUE, data points are not connected by
-#'   lines, prime is forced to be FALSE and runs analysis is not performed.
+#'   lines, prime is forced to be FALSE, and runs analysis is not performed.
 #'   Useful for comparison and funnel plots.
-#' @param main Character string specifying the title of the plot.
-#' @param xlab Character string specifying the x axis label.
-#' @param ylab Character string specifying the y axis label.
-#' @param plot Logical. If TRUE (default), plot chart.
-#' @param print Logical. if TRUE, prints return value.
+#' @param print.summary Logical. If TRUE, prints summary of tcc object.
 #' @param ... Further arguments to ggplot function.
 #'
 #' @details \code{tcc()} is a wrapper function that uses ggplot2 to create
 #'   multivariate run and control charts. It takes up to two grouping variables
 #'   to make one or two dimensional trellis plots.
 #'
-#' @return A list of of class tcc containing values and parameters of the tcc
-#'   plot.
+#' @return An object of class ggplot.
+#'
+#' @references Runs analysis: \itemize{ \item Jacob Anhoej, Anne Vingaard Olesen
+#'   (2014). Run Charts Revisited: A Simulation Study of Run Chart Rules for
+#'   Detection of Non-Random Variation in Health Care Processes. PLoS ONE 9(11):
+#'   e113825. doi: 10.1371/journal.pone.0113825 . \item Jacob Anhoej (2015).
+#'   Diagnostic Value of Run Chart Analysis: Using Likelihood Ratios to Compare
+#'   Run Chart Rules on Simulated Data Series. PLoS ONE 10(3): e0121349. doi:
+#'   10.1371/journal.pone.0121349 \item Mark F. Schilling (2012). The Surprising
+#'   Predictability of Long Runs. Math. Mag. 85, 141-149. \item Zhenmin Chen
+#'   (2010). A note on the runs test. Model Assisted Statistics and Applications
+#'   5, 73-77. } Calculation of control limits: \itemize{ \item   Douglas C.
+#'   Montgomery (2009). Introduction to Statistical Process Control, Sixth
+#'   Edition, John Wiley & Sons. \item James C. Benneyan (2001). Number-Between
+#'   g-Type Statistical Quality Control Charts for Monitoring Adverse Events.
+#'   Health Care Management Science 4, 305-318. \item Lloyd P. Provost, Sandra
+#'   K. Murray (2011). The Health Care Data Guide: Learning from Data for
+#'   Improvement. San Francisco: John Wiley & Sons Inc. \item David B. Laney
+#'   (2002). Improved control charts for attributes. Quality Engineering, 14(4),
+#'   531-537.}
 #'
 #' @examples
 #' # Run chart of 24 random normal variables
@@ -64,7 +95,7 @@
 #'
 #' # Build data frame for examples
 #' d <- data.frame(x = rep(1:24, 4),
-#'                 mo = (rep(seq(as.Date('2013-1-1'),
+#'                 mo = (rep(seq(as.Date('2014-1-1'),
 #'                               length.out = 24,
 #'                               by = 'month'),
 #'                           4)),
@@ -73,52 +104,44 @@
 #'                 g1 = rep(c('a', 'b'), each = 48),
 #'                 g2 = rep(c('A', 'B'), each = 24))
 #'
-#' # Single, one-dimensional run chart
-#' tcc(n, d, mo, data = subset(d, g1 == 'a' & g2 == 'A'))
-#'
-#' # Run chart with one grouping variable and two groups
-#' tcc(n, d, mo, g1 = g2, data = subset(d, g1 == 'a'))
-#'
 #' # Run chart with two grouping variables
 #' tcc(n, d, mo, g1 = g1, g2 = g2, data = d)
 #'
-#' # I chart
-#' tcc(n, d, mo, g1 = g1, g2 = g2, data = d, chart = 'i')
-#'
 #' # P chart
 #' tcc(n, d, mo, g1 = g1, g2 = g2, data = d, chart = 'p')
 #'
 #' # P chart with baseline fixed to the first 12 data points
 #' tcc(n, d, mo, g1 = g1, g2 = g2, data = d, chart = 'p', freeze = 12)
 #'
-#' # P chart with two breaks
-#' tcc(n, d, mo, g1 = g1, g2 = g2, data = d, chart = 'p', breaks = c(12, 18))
-#'
-#' # P chart with two data points excluded from calculations
-#' tcc(n, d, mo, g1 = g1, g2 = g2, data = d, chart = 'p', exclude = c(12, 18))
+#' # P chart with two breaks and summary output
+#' tcc(n, d, mo, g1 = g1, g2 = g2, data = d, chart = 'p',
+#'  breaks = c(12, 18), print.summary = TRUE)
 
-tcc <- function(n, d, x, g1, g2, breaks,
+tcc <- function(n, d, x, g1, g2, breaks, notes,
                 data,
-                chart      = c("run", "i", "mr", "xbar", "s",
-                               "t", "p", "c", "u", "g"),
-                multiply    = 1,
-                freeze      = NULL,
+                chart         = c("run", "i", "mr", "xbar", "s",
+                                  "t", "p", "c", "u", "g"),
+                multiply      = 1,
+                freeze        = NULL,
                 exclude,
-                sum.n       = FALSE,
-                neg.y       = TRUE,
-                cex         = 1,
-                pex         = 1,
-                dec         = 2,
-                ylim        = NULL,
-                date.format = NULL,
-                prime       = TRUE,
-                flip        = FALSE,
-                dots.only   = FALSE,
+                target        = NA,
+                n.sum         = FALSE,
+                y.neg         = TRUE,
+                y.percent     = FALSE,
+                y.expand      = NULL,
+                x.pad         = 1,
+                x.date.format = NULL,
+                cl.lab        = TRUE,
+                cl.decimals   = 2,
                 main,
-                xlab        = 'Subgroup',
-                ylab        = 'Indicator',
-                plot        = TRUE,
-                print       = FALSE,
+                xlab          = 'Subgroup',
+                ylab          = 'Value',
+                cex           = 1,
+                pex           = 1,
+                prime         = TRUE,
+                flip          = FALSE,
+                dots.only     = FALSE,
+                print.summary = FALSE,
                 ...) {
   # Get chart type
   type <- match.arg(chart)
@@ -147,6 +170,8 @@ tcc <- function(n, d, x, g1, g2, breaks,
       g1 <- data[,deparse(substitute(g1))]
     if(deparse(substitute(g2)) %in% colnames(data))
       g2 <- data[,deparse(substitute(g2))]
+    if(deparse(substitute(notes)) %in% colnames(data))
+      notes <- data[,deparse(substitute(notes))]
   }
 
   # Set missing denominator
@@ -156,11 +181,13 @@ tcc <- function(n, d, x, g1, g2, breaks,
 
   # Set missing subgroups
   if(missing(x))
-    x <- 1:length(n)
+    x <- seq_along(n)
   if(missing(g1))
     g1 <- rep(1, length(n))
   if(missing(g2))
     g2 <- rep(1, length(n))
+  if(missing(notes))
+    notes <- rep(NA, length(n))
 
   # Fix missing values
   cases <- complete.cases(n, d)
@@ -174,7 +201,7 @@ tcc <- function(n, d, x, g1, g2, breaks,
   }
 
   # Initialise data frame
-  df <- data.frame(n, d, x, g1, g2, cases)
+  df <- data.frame(n, d, x, g1, g2, cases, notes)
   df <- droplevels(df)
 
   # Build breaks variable
@@ -191,7 +218,7 @@ tcc <- function(n, d, x, g1, g2, breaks,
         breaks <- c(0, breaks, nrow(x))
         breaks <- sort(breaks)
         breaks <- diff(breaks)
-        breaks <- rep(1:length(breaks), breaks)
+        breaks <- rep(seq_along(breaks), breaks) #rep(1:length(breaks), breaks)
         x$breaks <- breaks
       }
       return(x)
@@ -214,22 +241,37 @@ tcc <- function(n, d, x, g1, g2, breaks,
   d3 <- aggregate(cbind(n.obs = cases) ~ x + g1 + g2 + breaks,
                   data = df,
                   FUN = sum,
-                  na.rm = TRUE)
+                  na.rm = TRUE,
+                  na.action = na.pass)
+  try(d4 <- aggregate(notes ~ x + g1 + g2 + breaks,
+                      data = df,
+                      FUN = paste,
+                      collapse=' | '),
+      silent = TRUE)
   df <- merge(d1, d2)
   df <- merge(df, d3)
+
+  if(exists('d4')) {
+    df <- merge(df, d4, all = T)
+  } else{
+    df$notes <- NA
+  }
+
+  # Check that subgroups are unique for T and G charts
+  if(any(type == c('t', 'g')) & max(df$n.obs, na.rm = TRUE) > 1)
+    stop('The grouping argument, \"x\", must contain unique values for T and G charts.')
+
   df <- df[order(df$x), ]
 
   # Calculate y variable
-  if(sum.n & no.d | type %in% c('c', 't', 'g')) {
+  if(n.sum & no.d | type %in% c('c', 't', 'g')) {
     df$y <- df$n
   } else {
     df$y <- df$n / df$d
   }
 
-  # df$y[is.nan(df$y)] <- NA
   df$y[df$d == 0] <- NA
 
-
   # Build exclude variable
   df$exclude <- FALSE
   if(!missing(exclude)) {
@@ -239,23 +281,28 @@ tcc <- function(n, d, x, g1, g2, breaks,
   }
 
   # Complete data frame
-  df                  <- split(df, list(df$g1, df$g2, df$breaks))
-  df                  <- lapply(df, fn, freeze = freeze, prime = prime, sum.n)
-  df                  <- lapply(df, runs.analysis)
-  df                  <- do.call(rbind, df)
-  row.names(df)       <- NULL
-  num.cols            <- c('n', 'd', 's', 'n.obs', 'cl', 'lcl', 'ucl', 'y')
-  mult.cols           <- c('cl', 'lcl', 'ucl', 'y')
-  df[num.cols]        <- sapply(df[num.cols], as.numeric)
-  df[mult.cols]       <- sapply(df[mult.cols], function(x) x * multiply)
-  df$limits.signal    <- df$y < df$lcl | df$y > df$ucl
-  x                   <- is.na(df$limits.signal)
-  df$limits.signal[x] <- FALSE
+  df                         <- split(df, list(df$g1, df$g2, df$breaks))
+  df                         <- lapply(df, fn,
+                                       freeze = freeze,
+                                       prime = prime,
+                                       n.sum)
+  df                         <- lapply(df, runs.analysis)
+  df                         <- do.call(rbind, df)
+  row.names(df)              <- NULL
+  num.cols                   <- c('n', 'd', 's', 'n.obs',
+                                  'cl', 'lcl', 'ucl', 'y')
+  mult.cols                  <- c('cl', 'lcl', 'ucl', 'y')
+  df[num.cols]               <- sapply(df[num.cols], as.numeric)
+  df[mult.cols]              <- sapply(df[mult.cols], function(x) x * multiply)
+  df$limits.signal           <- df$y < df$lcl | df$y > df$ucl
+  x                          <- is.na(df$limits.signal)
+  df$limits.signal[x]        <- FALSE
   df$ucl[!is.finite(df$ucl)] <- NA
   df$lcl[!is.finite(df$lcl)] <- NA
+  df$target                 <- as.numeric(target)
 
   # Prevent negative y axis if negy argument is FALSE
-  if(!neg.y & min(df$y, na.rm = TRUE) >= 0)
+  if(!y.neg & min(df$y, na.rm = TRUE) >= 0)
     df$lcl[df$lcl < 0] <- NA
 
   # Build return value
@@ -263,25 +310,31 @@ tcc <- function(n, d, x, g1, g2, breaks,
               main     = main,
               xlab     = xlab,
               ylab     = ylab,
-              sum.n    = sum.n,
+              n.sum    = n.sum,
               multiply = multiply,
               freeze   = freeze,
-              neg.y    = neg.y,
+              y.neg    = y.neg,
               prime    = prime)
-  class(tcc) <- 'tcc'
 
   # Plot and return
-  if(plot) {
-    plot.tcc(tcc, cex = cex, pex = pex, dec = dec, ylim = ylim,
-             date.format = date.format, flip = flip, dots.only = dots.only,
-             ...)
-  }
+  p <- plot.tcc(tcc, cex = cex, pex = pex, cl.decimals = cl.decimals,
+                x.pad = x.pad, cl.lab = cl.lab, y.expand = y.expand,
+                y.percent = y.percent, x.date.format = x.date.format,
+                flip = flip, dots.only = dots.only,
+                ...)
 
-  if(print) {
-    return(tcc)
-  } else {
-    invisible(tcc)
-  }
+  class(p) <- c('tcc', class(p))
+
+  if(print.summary)
+    print(summary(p))
+
+  return(p)
+
+  # if(print) {
+  #   return(tcc)
+  # } else {
+  #   invisible(tcc)
+  # }
 }
 
 tcc.run <- function(df, freeze, ...) {
@@ -563,8 +616,6 @@ runs.analysis <- function(df) {
   n.crossings.min <- qbinom(0.05, max(n.useful - 1, 0), 0.5)  # Chen 2010 (7)
   runs.signal     <- longest.run > longest.run.max ||
     n.crossings < n.crossings.min
-#   runs.signal     <- rep(runs.signal, length(y))
-#   df              <- cbind(df, runs.signal)
   df$runs.signal  <- runs.signal
 
   return(df)
@@ -627,42 +678,18 @@ c4 <- function(n) {
   return(x)
 }
 
-#' Plot trellis control chart
-#'
-#' Creates a plot of a tcc object
-#'
-#' @export
-#' @import ggplot2
-#' @importFrom scales date_format
-#' @param x List object returned from the tcc() function.
-#' @param y Ignored. Included for compatibility with generic plot function.
-#' @param cex Number indicating the amount by which text should be magnified.
-#' @param pex Number indicating the amount by which plotting symbols should be
-#'   magnified.
-#' @param dec Number of decimals on center and control line labels.
-#' @param ylim Range of y axis.
-#' @param date.format Date format of x axis labels. See \code{?strftime} for
-#'   date formats.
-#' @param flip Logical. If TRUE rotates the plot 90 degrees.
-#' @param dots.only Logical value. If TRUE, data points are not connected by
-#'   lines and runs analysis is not performed. Useful for comparison and funnel
-#'   plots.
-#' @param ... Further arguments to plot function.
-#'
-#' @return Creates a tcc plot.
-#'
-#' @examples
-#' p <- tcc(rnorm(24))
-#' plot(p)
 plot.tcc <- function(x,
-                     y           = NULL,
-                     cex         = 1,
-                     pex         = 1,
-                     ylim        = NULL,
-                     dec         = 2,
-                     date.format = '%Y-%m-%d',
-                     flip        = FALSE,
-                     dots.only   = FALSE,
+                     y             = NULL,
+                     cex           = 1,
+                     pex           = 1,
+                     y.expand      = NULL,
+                     y.percent     = FALSE,
+                     x.date.format = NULL,
+                     x.pad         = 1,
+                     cl.lab        = TRUE,
+                     cl.decimals   = 2,
+                     flip          = FALSE,
+                     dots.only     = FALSE,
                      ...) {
   df      <- x$df
   main    <- x$main
@@ -670,9 +697,11 @@ plot.tcc <- function(x,
   xlab    <- x$xlab
   freeze  <- x$freeze
   col1    <- rgb(093, 165, 218, maxColorValue = 255) # blue
-  col2    <- rgb(255, 165, 000, maxColorValue = 255) # amber
+  # col2    <- rgb(255, 165, 000, maxColorValue = 255) # amber
+  col2    <- rgb(241, 088, 084, maxColorValue = 255) # red
   col3    <- rgb(140, 140, 140, maxColorValue = 255) # grey
   col4    <- 'white'
+  col5    <-  rgb(096, 189, 104, maxColorValue = 255) # green
   cols    <- c('col1' = col1,
                'col2' = col2,
                'col3' = col3,
@@ -680,22 +709,20 @@ plot.tcc <- function(x,
   df$pcol <- ifelse(df$limits.signal, 'col2', 'col1')
   df$pcol <- ifelse(df$exclude, 'col4', df$pcol)
   df$lcol <- ifelse(df$runs.signal, 'col2', 'col3')
-
   p <- ggplot(df) +
-    theme_bw(base_size = 12 * cex) +
+    theme_bw(base_size = 11 * cex) +
     theme(panel.border     = element_rect(colour = 'grey70', size = 0.1),
           panel.grid.major = element_blank(),
           panel.grid.minor = element_blank(),
           axis.line        = element_blank(),
           axis.ticks       = element_line(colour = col3),
-          axis.title.y     = element_text(vjust = 1.2),
-          axis.title.x     = element_text(vjust = -0.2),
-          plot.title       = element_text(vjust = 1.2, hjust = 0),
+          axis.title.y     = element_text(margin = margin(r = 8)),
+          axis.title.x     = element_text(margin = margin(t = 8)),
+          plot.title       = element_text(hjust = 0, margin = margin(b = 8)),
           strip.background = element_rect(fill = 'grey90', colour = 'grey70'))
-
   p <- p +
     geom_line(aes_string(x = 'x', y = 'cl', colour = 'lcol', group = 'breaks'),
-              lwd = 0.3 * cex,
+              lwd = 0.6 * cex,
               na.rm = TRUE) +
     geom_line(aes_string(x = 'x', y = 'lcl', group = 'breaks'),
               colour = col3,
@@ -704,6 +731,11 @@ plot.tcc <- function(x,
     geom_line(aes_string(x = 'x', y = 'ucl', group = 'breaks'),
               colour = col3,
               lwd = 0.3 * cex,
+              na.rm = TRUE) +
+    geom_line(aes_string(x = 'x', y = 'target'),
+              colour = col5,
+              lty = 5,
+              lwd = 0.3 * cex,
               na.rm = TRUE)
 
   if(!dots.only) {
@@ -717,7 +749,8 @@ plot.tcc <- function(x,
                                  group = 'breaks',
                                  fill = 'pcol'),
                       colour = col1,
-                      size = 2.5 * pex * cex,
+                      stroke = 0.5,
+                      size = 2 * pex * cex,
                       shape = 21,
                       na.rm = TRUE) +
     # Colour centre line according to runs analysis
@@ -740,39 +773,6 @@ plot.tcc <- function(x,
     p <- p +
       theme(panel.border = element_blank(),
             axis.line = element_line(size = 0.1, colour = col3))
-    # Add centre line label
-    if(length(na.omit(df$cl))) {
-      p <- p +
-        geom_text(aes_string(x = 'tail(x, 1)', y = 'tail(na.omit(cl), 1)',
-                             label = 'sround(tail(cl, 1), dec)'),
-#         geom_text(aes_string(x = 'tail(x, 1)', y = 'mean(cl, na.rm = TRUE)',
-#                              label = 'sround(mean(cl, na.rm = TRUE), dec)'),
-                  hjust = -0.15,
-                  col = 'grey30',
-                  size = 3)
-    }
-    # Add upper control limit label
-    if(length(na.omit(df$ucl))) {
-      p <- p +
-        geom_text(aes_string(x = 'tail(x, 1)', y = 'tail(na.omit(ucl), 1)',
-                             label = 'sround(tail(na.omit(ucl), 1), dec)'),
-#         geom_text(aes_string(x = 'tail(x, 1)', y = 'mean(ucl, na.rm = TRUE)',
-#                              label = 'sround(mean(ucl, na.rm = T), dec)'),
-                  hjust = -0.15,
-                  col = 'grey30',
-                  size = 3)
-    }
-    # Add lower control limit label
-    if(length(na.omit(df$lcl))) {
-      p <- p +
-        geom_text(aes_string(x = 'tail(x, 1)', y = 'tail(na.omit(lcl), 1)',
-                             label = 'sround(tail(na.omit(lcl), 1), dec)'),
-#         geom_text(aes_string(x = 'tail(x, 1)', y = 'mean(lcl, na.rm = TRUE)',
-#                              label = 'sround(mean(lcl, na.rm = TRUE), dec)'),
-                  hjust = -0.15,
-                  col = 'grey30',
-                  size = 3)
-    }
   }
 
   # Add vertical line to mark freeze point
@@ -783,24 +783,109 @@ plot.tcc <- function(x,
   }
 
   # Format data axis
-  if(inherits(df$x, c('Date')) & !is.null(date.format)) {
-    p <- p + scale_x_date(labels = date_format(date.format))
+  if(!is.null(x.date.format)) {
+    if(inherits(df$x, 'Date')) {
+      p <- p + scale_x_date(date_labels = x.date.format)
+    }
+    if(inherits(df$x, 'POSIXt')) {
+      p <- p + scale_x_datetime(date_labels = x.date.format)
+    }
   }
 
-  if(inherits(df$x, c('POSIXct')) & !is.null(date.format)) {
-    p <- p + scale_x_datetime(labels = date_format(date.format))
-  }
 
   # Add title and axis labels
   p <- p +
     labs(title = main, x = xlab, y = ylab) +
-    coord_cartesian(ylim = ylim)
+    expand_limits(y = y.expand)
+    # coord_cartesian(ylim = ylim)
+
+  # Add center line label
+  if(cl.lab) {
+    p <- p + geom_text(aes_string(x = 'tail(x, 1)', y = 'cl',
+                                  label = 'paste0("  ", sround(cl, cl.decimals))',
+                                  hjust = 0),
+                       # hjust = -0.25,
+                       # nudge_x = 1,
+                       check_overlap = TRUE,
+                       col = 'grey30',
+                       size = 3 * cex)
+    if(inherits(df$x, c('Date', 'POSIXt', 'numeric', 'integer'))) {
+      p <- p + expand_limits(x = max(df$x) + diff(range(df$x)) * 0.08 * x.pad)
+    }
+  }
+
+  if(sum(!is.na(df$notes))) {
+    p <- p +
+      geom_label_repel(aes_string(x = 'x', y = 'y', label = 'notes'),
+                       size = 3 * cex,
+                       point.padding = unit(2, 'points'),
+                       na.rm = TRUE)
+  }
 
   # Flip chart
   if(flip) {
     p <- p + coord_flip()
   }
 
+  if(y.percent) {
+    p <- p + scale_y_continuous(labels = scales::percent)
+  }
+
   # Plot chart
-  plot(p)
+  # plot(p)
+  return(p)
+}
+
+#' Summarise Trellis Control Charts
+#'
+#' Summary function for tcc objects.
+#'
+#' @export
+#'
+#' @param object tcc object
+#' @param ... Ignored. Included for compatibility with generic summary function.
+#'
+#' @return A data frame with summary statistics of the tcc object.
+#'
+#' @examples
+#' # Build data frame for example
+#' d <- data.frame(x = rep(1:24, 4),
+#'                 mo = (rep(seq(as.Date('2014-1-1'),
+#'                               length.out = 24,
+#'                               by = 'month'),
+#'                           4)),
+#'                 n = rbinom(4 * 24, 100, 0.5),
+#'                 d = round(runif(4 * 24, 90, 110)),
+#'                 g1 = rep(c('a', 'b'), each = 48),
+#'                 g2 = rep(c('A', 'B'), each = 24))
+#'
+#' # P chart
+#' p <- tcc(n, d, mo, g1 = g1, g2 = g2, breaks = 12, data = d, chart = 'p')
+#' plot(p)
+#' summary(p)
+
+summary.tcc <- function(object, ...) {
+  d <- object$data
+  x1 <- aggregate(n.obs ~ g1 + g2 + breaks,
+                  data = d,
+                  length)
+  x2 <- aggregate(cbind(n.useful = y != cl) ~ g1 + g2 + breaks,
+                  data = d,
+                  sum,
+                  na.rm = TRUE)
+  x3 <- aggregate(cbind(cl, lcl, ucl) ~ g1 + g2 + breaks,
+                  data = d,
+                  tail, 1,
+                  na.action = na.pass)
+  x4 <- aggregate(cbind(runs.signal, limits.signal) ~ g1 + g2 + breaks,
+                  data = d,
+                  max,
+                  na.rm = TRUE)
+  x4[4:5] <- apply(x4[4:5], 2, as.logical)
+
+  x <- merge(x1, x2)
+  x <- merge(x, x3)
+  x <- merge(x, x4)
+
+  return(x)
 }
